@@ -1,7 +1,7 @@
 #' @export
 print.colonization <- function(x, ...)
 {
-    cat("Total of inferred colonization events",
+    cat("Minimum number of inferred colonization events",
         sep = "\n")
     cat(x$Total,
         sep = "\n")
