@@ -1,11 +1,11 @@
 #' @export
 print.maxCol <- function(x, ...) {
-    cat("Maximum of estimated colonization events:",
+    cat("Asymptote estimators of colonization events:",
         sep = "\n")
     print(x$Summary)
     cat("",
         sep = "\n")
-    cat(paste("Minimum and maximum determined by a interval of conficende of ",
+    cat(paste("Minimum and maximum determined by a confidence interval of ",
               x$ConfintLevel * 100,
               "%",
               sep = ""),
